@@ -1,3 +1,6 @@
+#[macro_use]
+extern crate thiserror;
+
 mod iter;
 
 pub use self::iter::Iter;
@@ -13,8 +16,9 @@ pub type Locale<'a> = &'a str;
 pub type LocaleMap<'a> = BTreeMap<Locale<'a>, Value<'a>>;
 pub type Value<'a> = &'a str;
 
-#[derive(Debug, Copy, Clone, PartialEq, Eq)]
+#[derive(Debug, Copy, Clone, Error, PartialEq, Eq)]
 pub enum DecodeError {
+    #[error("path does not contain a valid app ID")]
     AppID,
 }
 
@@ -22,6 +26,7 @@ pub enum DecodeError {
 pub struct DesktopEntry<'a> {
     pub appid: &'a str,
     pub groups: Groups<'a>,
+    pub path: &'a Path,
 }
 
 impl<'a> DesktopEntry<'a> {
@@ -53,7 +58,7 @@ impl<'a> DesktopEntry<'a> {
         self.desktop_entry("Comment", locale)
     }
 
-    pub fn decode<'b>(path: &'b Path, input: &'b str) -> Result<DesktopEntry<'b>, DecodeError>  {
+    pub fn decode<'b>(path: &'b Path, input: &'b str) -> Result<DesktopEntry<'b>, DecodeError> {
         let appid = path
             .file_stem()
             .ok_or(DecodeError::AppID)?
@@ -105,7 +110,11 @@ impl<'a> DesktopEntry<'a> {
             }
         }
 
-        Ok(DesktopEntry { appid, groups })
+        Ok(DesktopEntry {
+            appid,
+            groups,
+            path,
+        })
     }
 
     pub fn desktop_entry(&self, key: &str, locale: Option<&str>) -> Option<&'a str> {
@@ -204,7 +213,7 @@ pub enum PathSource {
     System,
     SystemFlatpak,
     SystemSnap,
-    Other(String)
+    Other(String),
 }
 
 pub fn default_paths() -> Vec<(PathSource, PathBuf)> {
@@ -230,4 +239,4 @@ pub fn default_paths() -> Vec<(PathSource, PathBuf)> {
         ),
         (PathSource::System, PathBuf::from("/usr/share/applications")),
     ]
-}
\ No newline at end of file
+}
